@@ -7,7 +7,7 @@
 
 from tensorflow.keras.utils import plot_model
 from deepforecast.features import SparseColumn, SequenceColumn
-from deepforecast.models.sttf import STTF
+from deepforecast.models import STTF
 
 attr_feats = ["age", "user", "platform"]
 sequence_feats = ["history", "future"]
